==> fine-web-0.0.1-20220919.091035-231.jar: beetlsql/gen/GenFormFlow.md <==
select
===
select  @pageTag(){
       t.ID as form_id,
       t.form_code,
       t.form_name,
       t.flow_cat_id,
       tt.id,
       tt.apply_orgs,
       (select group_concat(o.ABBR)
          from bas_org o
         where comparestr( tt.apply_orgs,o.org_id) > 0) AS apply_orgs_name,
       tt.flow_code
      @}
  from GEN_FORM t
  left join GEN_FORM_FLOW tt
    on t.id = tt.form_id
    and tt.is_use='Y'
left join STF_BUSINESS_PROCESS s
on t.flow_code = s.design_name
 where t.is_use = 'Y'
   and t.flow_cat_id is not null
   and ifnull(s.share_type, 0) <> '1'
@if(!isEmpty(search)){
and(
 upper(t.form_name) like #search#  or 
 upper(t.form_code) like #search#  or 
 upper(tt.FLOW_CODE) like #search#  
)@}
@if(!isEmpty(flowsql)){
#text(flowsql)#
@}
@pageIgnoreTag(){
	@if(isEmpty(sort)){
   	 order by t.ID desc
    @}
    @if(!isEmpty(sort)){
   	 order by #text(sort)# #text(order)#
    @}
@}

getFormItem
===
select t.act_id,t.item_id, t.is_show, t.is_editable, t.is_required,t.item_label
  from GEN_ACT_ITEM t, GEN_FORM_FLOW tt
 where t.setting_id = tt.id
 and t.is_use = 'Y'
 and tt.is_use = 'Y'
 @if(!isEmpty(itemId)){
   and t.item_id = #itemId#
 @} 
   and tt.form_id = #formId#
   and comparestr(tt.apply_orgs,#text(orgId)#) > 0
   and t.act_id=#actId#
    @if(!isEmpty(isPishiForm)){
		and t.PANEL_TYPE='10'
   	@}else{
		and (t.PANEL_TYPE='0' or t.PANEL_TYPE is null)
   	@}

getFormFile
===
select t.act_id,
       t.is_show,
       t.is_editable,
       t.is_required,
       t.show_local,
       t.show_visual,
       t.show_scan
  from GEN_ACT_FILE t, GEN_FORM_FLOW tt
 where t.setting_id = tt.id
   and t.FILE_TYPE_ID = #fileTypeId#
   and tt.form_id = #formId#
   and comparestr(tt.apply_orgs,#text(orgId)#) > 0
   and t.act_id=#actId#
   
checkEntity
===
select count(1) 
from GEN_FORM_FLOW t
where t.is_use = 'Y'
and t.FORM_ID = #formId# 
and comparestr(t.apply_orgs,#applyOrgs#) > 0 
and t.ID <> #id#
and t.is_use = 'Y'

findByFormIdAndApplyOrgs
===
select t.*
  from GEN_FORM_FLOW t
 where t.is_use = 'Y'
@if(!isEmpty(formId)){
   and t.form_id = #formId# 
@} 
@if(!isEmpty(flowCode)){
   and t.flow_code = #flowCode# 
@}
@if(!isEmpty(orgId)){
 and comparestr(t.apply_orgs, #orgId#) > 0
@}

==> fine-web-0.0.2-20220913.113206-173.jar: beetlsql/gen/GenFormFlow.md <==
select
===
select  @pageTag(){
       t.ID as form_id,
       t.form_code,
       t.form_name,
       t.flow_cat_id,
       tt.id,
       tt.apply_orgs,
       (select group_concat(o.ABBR)
          from bas_org o
         where comparestr( tt.apply_orgs,o.org_id) > 0) AS apply_orgs_name,
       tt.flow_code
      @}
  from GEN_FORM t
  left join GEN_FORM_FLOW tt
    on t.id = tt.form_id
    and tt.is_use='Y'
left join STF_BUSINESS_PROCESS s
on t.flow_code = s.design_name
 where t.is_use = 'Y'
   and t.flow_cat_id is not null
@if(flowModel!='normal'){
   and ifnull(s.share_type, 0) <> '1'
@}
@if(!isEmpty(search)){
and(
 upper(t.form_name) like #search#  or 
 upper(t.form_code) like #search#  or 
 upper(tt.FLOW_CODE) like #search# or
 upper((select group_concat(o.ABBR)
           from bas_org o
          where comparestr( tt.apply_orgs,o.org_id) > 0)) like  #search#
)@}
@if(!isEmpty(flowsql)){
#text(flowsql)#
@}
@pageIgnoreTag(){
	@if(isEmpty(sort)){
   	 order by t.ID desc
    @}
    @if(!isEmpty(sort)){
   	 order by #text(sort)# #text(order)#
    @}
@}

getFormItem
===
select t.act_id,t.item_id, t.is_show, t.is_editable, t.is_required,t.item_label,
		t.disable,
		t.dataoptions,
		t.editable_Act,
		t.default_Value,
		t.singlerow
  from GEN_ACT_ITEM t, GEN_FORM_FLOW tt
 where t.setting_id = tt.id
 and t.is_use = 'Y'
 and tt.is_use = 'Y'
 @if(!isEmpty(itemId)){
   and t.item_id = #itemId#
 @} 
   and tt.form_id = #formId#
   and comparestr(tt.apply_orgs,#text(orgId)#) > 0
   and t.act_id=#actId#
    @if(!isEmpty(isPishiForm)){
		and t.PANEL_TYPE='10'
   	@}else{
		and (t.PANEL_TYPE='0' or t.PANEL_TYPE is null)
   	@}

getFormFile
===
select t.act_id,
       t.is_show,
       ifnull(t.is_editable,'N') is_editable,
       t.is_required,
       t.show_local,
       t.show_visual,
       t.show_scan
  from GEN_ACT_FILE t, GEN_FORM_FLOW tt
 where t.setting_id = tt.id
   and t.FILE_TYPE_ID = #fileTypeId#
   and tt.form_id = #formId#
   and comparestr(tt.apply_orgs,#text(orgId)#) > 0
   and t.act_id=#actId#
   
checkEntity
===
select count(1) 
from GEN_FORM_FLOW t
where t.is_use = 'Y'
and t.FORM_ID = #formId# 
and comparestr(t.apply_orgs,#applyOrgs#) > 0 
and t.ID <> #id#
and t.is_use = 'Y'

findByFormIdAndApplyOrgs
===
select t.*
  from GEN_FORM_FLOW t
 where t.is_use = 'Y'
@if(!isEmpty(formId)){
   and t.form_id = #formId# 
@} 
@if(!isEmpty(flowCode)){
   and t.flow_code = #flowCode# 
@}
@if(!isEmpty(orgId)){
 and comparestr(t.apply_orgs, #orgId#) > 0
@}
